-- Reskin the clarifier, duplicate an assembling-machine variant
local clarifier_entity = data.raw.furnace["clarifier"]
local clarifier_item = data.raw.item["clarifier"]

local shadows = make_4way_animation_from_spritesheet({
    filename = "__fadeout_bug_report__/graphics/entity/clarifier/clarifier-shadow.png",
    priority = "extra-high",
    width = 189,
    height = 184,
    shift = util.by_pixel(9.5, 1),
    draw_as_shadow = true,
    hr_version = {
        filename = "__fadeout_bug_report__/graphics/entity/clarifier/hr-clarifier-shadow.png",
        priority = "extra-high",
        width = 374,
        height = 365,
        shift = util.by_pixel(10, 0),
        draw_as_shadow = true,
        scale = 0.5,
    },
})

local pipe_properties = {
    north = {normal = 0, hr = 0},
    -- East frame mapping: 2-All, 12-30, 13-31, 14-32, 15-33, 16-34, 15,35, 16-36
    east = {2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 12, 13, 14,
        15, 16, 17, 18, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2},
    south = {normal = 189*2, hr = 374*2},
    -- West frame mapping: 4-All, 5-1, 6-2, 7-3, 8-61, 9-62, 10-63, 11-64
    west = {5, 6, 7, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
        4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 8, 9.5, 10, 11}
}

local icons = {
    icon = "__fadeout_bug_report__/graphics/icons/clarifier/clarifier-icon-base.png",
    icon_size = 64,
    icon_mipmaps = 4,
}

local tinted_icons = {
    icon = "__fadeout_bug_report__/graphics/icons/clarifier/clarifier-icon-base.png",
    icon_size = 64,
    icon_mipmaps = 4,
    tint = util.color("FF0000"),
}

local function get_pipe_connections(direction, is_animated)
    if is_animated then
        return {
            filename = "__fadeout_bug_report__/graphics/entity/clarifier/clarifier-pipe-connections.png",
            priority = "extra-high",
            width = 189,
            height = 184,
            frame_count = 18,
            line_length = 6,
            animation_speed = 0.5,
            frame_sequence = pipe_properties[direction],
            shift = util.by_pixel(9.5, 1),
            hr_version = {
                filename = "__fadeout_bug_report__/graphics/entity/clarifier/hr-clarifier-pipe-connections.png",
                priority = "extra-high",
                width = 374,
                height = 365,
                frame_count = 18,
                line_length = 6,
                animation_speed = 0.5,
                frame_sequence = pipe_properties[direction],
                shift = util.by_pixel(10, 0),
                scale = 0.5,
            }
        }
    else
        return {
            filename = "__fadeout_bug_report__/graphics/entity/clarifier/clarifier-pipe-connections.png",
            priority = "extra-high",
            width = 189,
            height = 184,
            x = pipe_properties[direction].normal,
            shift = util.by_pixel(9.5, 1),
            hr_version = {
                filename = "__fadeout_bug_report__/graphics/entity/clarifier/hr-clarifier-pipe-connections.png",
                priority = "extra-high",
                width = 374,
                height = 365,
                x = pipe_properties[direction].hr,
                shift = util.by_pixel(10, 0),
                scale = 0.5,
            }
        }
    end
end

clarifier_entity.animation = {
    filename = "__fadeout_bug_report__/graphics/entity/clarifier/clarifier-base.png",
    priority = "extra-high",
    frame_count = 64,
    line_length = 8,
    animation_speed = 0.5,
    width = 189,
    height = 184,
    shift = util.by_pixel(9.5, 1),
    hr_version = {
        filename = "__fadeout_bug_report__/graphics/entity/clarifier/hr-clarifier-base.png",
        priority = "extra-high",
        frame_count = 64,
        line_length = 8,
        animation_speed = 0.5,
        width = 374,
        height = 365,
        shift = util.by_pixel(10, 0),
        scale = 0.5,
    },
}

clarifier_entity.working_visualisations = {
    -- Shadows
    {
        always_draw = true,
        north_animation = shadows.north,
        east_animation = shadows.east,
        south_animation = shadows.south,
        west_animation = shadows.west,
    },

    -- Pipes North/South
    {
        always_draw = true,
        north_animation = get_pipe_connections("north"),
        south_animation = get_pipe_connections("south"),
    },

    -- Pipes East/West
    {
        always_draw = true,
        render_layer = "higher-object-under",
        east_animation = get_pipe_connections("east", true),
        west_animation = get_pipe_connections("west", true),
    },

    -- Recipe mask
    {
        apply_recipe_tint = "primary",
        fadeout = true,
        animation = {
            filename = "__fadeout_bug_report__/graphics/entity/clarifier/clarifier-recipe-mask.png",
            priority = "extra-high",
            frame_count = 64,
            line_length = 8,
            animation_speed = 0.5,
            width = 189,
            height = 184,
            shift = util.by_pixel(9.5, 1),
            hr_version = {
                filename = "__fadeout_bug_report__/graphics/entity/clarifier/hr-clarifier-recipe-mask.png",
                priority = "extra-high",
                frame_count = 64,
                line_length = 8,
                animation_speed = 0.5,
                width = 374,
                height = 365,
                shift = util.by_pixel(10, 0),
                scale = 0.5,
            },
        }
    },
}

clarifier_entity.icons = {icons}
clarifier_item.icons = {icons}

-- Make the assembling machine variant
local debug_clarifier = util.copy(clarifier_entity)
debug_clarifier.type = "assembling-machine"
debug_clarifier.name = "debug-clarifier"
debug_clarifier.icons = {tinted_icons}
debug_clarifier.animation.tint = util.color("FF0000")
debug_clarifier.animation.hr_version.tint = util.color("FF0000")

data:extend({
    -- Item
    {
        type = "item",
        name = "debug-clarifier",
        icons = {tinted_icons},
        subgroup = "water-treatment-building",
        order = "c[clarifier]",
        place_result = "debug-clarifier",
        stack_size = 10,
    },

    -- Entity
debug_clarifier,
})
